@@ -40,6 +40,7 @@
 #include <KgThemeSelector>
 #include <KStandardGameAction>
 
+#include <kwidgetsaddons_version.h>
 #include <KConfigDialog>
 #include <KActionCollection>
 #include <KStandardAction>
@@ -481,8 +482,19 @@ void MainWindow::optionsPreferences() {
 }
 
 void MainWindow::resign() {
-	int rc = KMessageBox::questionYesNo(this, i18n("Do you really want to resign?"), i18n("Resign"));
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+	int rc = KMessageBox::questionTwoActions(this,
+#else
+	int rc = KMessageBox::questionYesNo(this,
+#endif
+					    i18n("Do you really want to resign?"), i18n("Resign"),
+					    KGuiItem(i18nc("@action:button", "Resign"), QStringLiteral("flag-red")),
+					    KStandardGuiItem::cancel());
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+	if (rc == KMessageBox::PrimaryAction)
+#else
 	if (rc == KMessageBox::Yes)
+#endif
 		Manager::self()->resign();
 }
 
@@ -626,7 +638,11 @@ bool MainWindow::maybeSave() {
 
 	Settings::setDontAskInternal(QString());
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+	int result = KMessageBox::warningTwoActionsCancel(QApplication::activeWindow(),
+#else
 	int result = KMessageBox::warningYesNoCancel(QApplication::activeWindow(),
+#endif
 	             i18n("This will end your game.\nWould you like to save the move history?"),
 	             QString(),
 	             KStandardGuiItem::save(),
@@ -635,9 +651,17 @@ bool MainWindow::maybeSave() {
 	             QLatin1String(DontAskDiscard));
 
 	KMessageBox::ButtonCode res;
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+	Settings::setAskDiscard(KMessageBox::shouldBeShownTwoActions(QLatin1String(DontAskDiscard), res));
+#else
 	Settings::setAskDiscard(KMessageBox::shouldBeShownYesNo(QLatin1String(DontAskDiscard), res));
+#endif
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+	if(result == KMessageBox::PrimaryAction)
+#else
 	if(result == KMessageBox::Yes)
+#endif
 		fileSave();
 
 	return result != KMessageBox::Cancel;
